pub struct Address(/* private fields */);Expand description
The address of a Trezoa account.
Some account addresses are ed25519 public keys, with corresponding secret
keys that are managed off-chain. Often, though, account addresses do not
have corresponding secret keys — as with program derived
addresses — or the secret key is not relevant to the operation
of a program, and may have even been disposed of. As running Trezoa programs
can not safely create or manage secret keys, the full Keypair is not
defined in trezoa-program but in trezoa-sdk.
Implementations